import {
  select,
  csv,
  scaleLinear,
  axisLeft,
  axisBottom,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  const xValue = (d) => d.Weight;
  const yValue = (d) => d.MPG;
  const margin = {
    top: 60,
    right: 40,
    bottom: 88,
    left: 150,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleLinear()
    .domain(d3.extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(d3.extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  const g = svg
    .append('g')
    .attr('transform', `translate(0,${innerHeight})`);

  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  svg
    .selectAll('circle')
    .data(data)
    .enter()
    .append('circle')
    .attr('cy', (d) => yScale(yValue(d)))
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('r', (d) => d.Weight / 500);
};

csv('data.csv').then((data) => {
  data.forEach((d) => {
    d.Weight = +d.Weight;
    d.MPG = +d.MPG;
  });
  render(data);
});
